<?php
/*
Plugin Name: Cognito Forms
Plugin URI: http://wordpress.org/plugins/cognito-forms/
Description: Cognito Forms is a free online form builder that integrates seemlessly with WordPress. Create contact forms, registrations forms, surveys, and more!
Version: 2.0.0
Author: Cognito Apps
Author URI: https://www.cognitoforms.com
*/

/**
 * Cognito Forms WordPress Plugin.
 *
 * The Cognito Forms WordPress Plugin is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License, version 2, as
 * published by the Free Software Foundation.
 *
 * The Cognito Forms WordPress Plugin is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Block Initializer.
 */
require_once plugin_dir_path( __FILE__ ) . 'src/init.php';

/**
 * The Plugin
 */

if ( !class_exists('CognitoFormsPlugin') ) {
	class CognitoFormsPlugin {
		// Initialization actions
		private static $actions = array(
			'admin_init',
			'admin_menu'
		);

		// Registers plug-in actions
		private function addActions($actions) {
			foreach($actions as $action)
				add_action($action, array($this, $action));
    }

		// Registers tinyMCE filters
		private function addFilters($filters) {
			foreach($filters as $filter)
				add_filter($filter, array($this, $filter));
		}

		// Entrypoint
		public function __construct() {
			$this->addActions(self::$actions);
		}

		// Initialize plug-in
		public function admin_init() {
			if(!current_user_can('edit_posts') && !current_user_can('edit_pages')) return;

			register_setting('cognito_plugin', 'cognito_api_key');
			register_setting('cognito_plugin', 'cognito_admin_key');
			register_setting('cognito_plugin', 'cognito_public_key');
			register_setting('cognito_plugin', 'cognito_organization');

			// If the flag to delete options was passed-in, delete them
			if (isset($_GET['cog_clear']) && $_GET['cog_clear'] == '1') {
				delete_option('cognito_api_key');
				delete_option('cognito_admin_key');
				delete_option('cognito_public_key');
				delete_option('cognito_organization');
			}

			// Add tinyMCE plug-in
			if(get_user_option('rich_editing') == 'true') {
				$this->addfilters(array(
					'mce_buttons',
					'mce_external_plugins'
				));
			}
		}

		// Set up tinyMCE buttons
		public function mce_buttons($buttons) {
			array_push($buttons, '|', 'cognito');
			return $buttons;
		}

		// Initialize tinyMCE plug-in
		public function mce_external_plugins($plugins) {
			$plugins['cognito'] = plugin_dir_url( __FILE__ ) . 'tinymce/plugin.js';
			return $plugins;
		}

		// Initialize administration menu (left-bar)
		public function admin_menu() {
			add_menu_page('Cognito Forms', 'Cognito Forms', 'manage_options', 'Cognito', array($this, 'main_page'), plugin_dir_url( __FILE__ ).'cogicon.ico');
			add_submenu_page('Cognito', 'Cognito Forms', 'View Forms', 'manage_options', 'Cognito', array($this, 'main_page'));
			add_submenu_page('Cognito', 'Create Form', 'New Form', 'manage_options', 'CognitoCreateForm', array($this, 'main_page'));
			add_submenu_page('Cognito', 'Templates', 'Templates', 'manage_options', 'CognitoTemplates', array($this, 'main_page'));

			add_options_page('Cognito Options', 'Cognito Forms', 'manage_options', 'CognitoOptions', array($this, 'options_page'));
		}

		// Entrypoint for Cognito Forms access
		public function main_page() {
			include 'templates/main.php';
		}

		public function options_page() {
			include 'templates/options.php';
		}
	}
	new CognitoFormsPlugin;
}
